@@ -2,7 +2,7 @@ package Term::Table::Cell;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Term::Table::LineBreak();
 use Term::Table::Util qw/uni_length/;
@@ -66,7 +66,7 @@ sub value_width {
     while (@parts) {
         my $text = shift @parts;
         my $sep  = shift @parts || '';
-        my $len = uni_length("$text$sep");
+        my $len = uni_length("$text");
         $max = $len if $len > $max;
     }
 
